Skip to contents

An exercice to check your Git's core.editor is set correctly. https://docs.github.com/es/get-started/git-basics/associating-text-editors-with-git

Usage

exo_check_editor(parent_path)

Arguments

parent_path

Path where to create the exercise repo

Value

The path to the new project

Workflow

Running the function will create the exercise as a new folder in parent_path. If called from RStudio or Positron, the function will open a new R session in that IDE. If not, the user will need to navigate to the path returned by the function, and launch an R session from there. The new R session will display messages about what challenge to solve, and running the tip() function from that new R session will display additional guiance.

git config, git commit --allow-empty.

Examples

if (FALSE) { # interactive()
parent_path <- withr::local_tempdir()
path <- exo_check_editor(parent_path = parent_path)
}