"Oh shit, I accidentally committed to the wrong branch!"
Source:R/exo-committed-to-wrong.R
exo_committed_to_wrong.RdWorkflow
Running the function will create the exercise as a new folder in parent_path.
If called from RStudio or Positron, the function will open a new R session in
that IDE.
If not, the user will need to navigate to the path returned by the function,
and launch an R session from there.
The new R session will display messages about what challenge to solve,
and running the tip() function from that new R session will display
additional guiance.
Examples
if (FALSE) { # interactive()
parent_path <- withr::local_tempdir()
path <- exo_committed_to_wrong(parent_path = parent_path)
}