"Oh shit, I need to undo a commit from like 5 commits ago!"
Source:R/exo-undo-commit.R
exo_undo_commit.RdTo go with https://ohshitgit.com/#undo-a-commit
Workflow
Running the function will create the exercise as a new folder in parent_path.
If called from RStudio or Positron, the function will open a new R session in
that IDE.
If not, the user will need to navigate to the path returned by the function,
and launch an R session from there.
The new R session will display messages about what challenge to solve,
and running the tip() function from that new R session will display
additional guiance.
Examples
if (FALSE) { # interactive()
parent_path <- withr::local_tempdir()
path <- exo_undo_commit(parent_path = parent_path)
}