I want to find the commit ID and message for HEAD~5 and HEAD^^.
The tool for that is git rev-parse combined with git log or git show.
More on ancestry references: https://git-scm.com/book/be/v2/Git-Tools-Revision-Selection.html#_ancestry_references.
Workflow
Running the function will create the exercise as a new folder in parent_path.
If called from RStudio or Positron, the function will open a new R session in
that IDE.
If not, the user will need to navigate to the path returned by the function,
and launch an R session from there.
The new R session will display messages about what challenge to solve,
and running the tip() function from that new R session will display
additional guiance.
Examples
if (FALSE) { # interactive()
parent_path <- withr::local_tempdir()
path <- exo_revparse(parent_path = parent_path)
}