"Oh shit, I did something terribly wrong, please tell me git has a magic time machine!?!"
Source:R/exo-time-machine.R
exo_time_machine.RdTo go with https://ohshitgit.com/#magic-time-machine
Workflow
Running the function will create the exercise as a new folder in parent_path.
If called from RStudio or Positron, the function will open a new R session in
that IDE.
If not, the user will need to navigate to the path returned by the function,
and launch an R session from there.
The new R session will display messages about what challenge to solve,
and running the tip() function from that new R session will display
additional guiance.
Examples
if (FALSE) { # interactive()
parent_path <- withr::local_tempdir()
path <- exo_time_machine(parent_path = parent_path)
}